==> amanda_2.4.4p3.orig.tar.gz: amanda-2.4.4p3/common-src/statfs.h <==
/*
 * Amanda, The Advanced Maryland Automatic Network Disk Archiver
 * Copyright (c) 1991-1998 University of Maryland at College Park
 * All Rights Reserved.
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of U.M. not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  U.M. makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * U.M. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL U.M.
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Authors: the Amanda Development Team.  Its members are listed in a
 * file named AUTHORS, in the root directory of this distribution.
 */
/*
 * $Id: statfs.h,v 1.3 1998/07/04 00:18:58 oliva Exp $
 *
 * interface to statfs module
 */
#include "amanda.h"

typedef struct generic_fs_stats {
    long total;		/* total KB in filesystem */
    long avail;		/* KB available to non-superuser */
    long free;		/* KB free for superuser */

    long files;		/* total # of files in filesystem */
    long favail;	/* # files avail for non-superuser */
    long ffree;		/* # files free for superuser */
} generic_fs_stats_t;

int get_fs_stats P((char *dir, generic_fs_stats_t *sp));

==> amanda_2.5.2p1.orig.tar.gz: amanda-2.5.2p1/common-src/statfs.h <==
/*
 * Amanda, The Advanced Maryland Automatic Network Disk Archiver
 * Copyright (c) 1991-1998 University of Maryland at College Park
 * All Rights Reserved.
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of U.M. not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  U.M. makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * U.M. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL U.M.
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Authors: the Amanda Development Team.  Its members are listed in a
 * file named AUTHORS, in the root directory of this distribution.
 */
/*
 * $Id: statfs.h,v 1.4 2006/05/25 01:47:12 johnfranks Exp $
 *
 * interface to statfs module
 */
#ifndef STATFS_H
#define STATFS_H

#include "amanda.h"

typedef struct generic_fs_stats {
    off_t total;		/* total KB in filesystem */
    off_t avail;		/* KB available to non-superuser */
    off_t free;		/* KB free for superuser */

    off_t files;		/* total # of files in filesystem */
    off_t favail;		/* # files avail for non-superuser */
    off_t ffree;		/* # files free for superuser */
} generic_fs_stats_t;

int get_fs_stats(char *dir, generic_fs_stats_t *sp);

#endif	/* !STATFS_H */
